package com.remobjects.elements.system;

import java.math.BigInteger;

public final class UnsignedLong extends Number implements Comparable<UnsignedLong> {
    public static final long MAX_VALUE = -1;
    public static final long MIN_VALUE = 0;
    private long fValue;

    public UnsignedLong(long j) {
        this.fValue = j;
    }

    public UnsignedLong(String str) {
        this.fValue = parseLong(str, 10);
    }

    private static int UnsignedCompare(long j, long j2) {
        return Long.compare(j - Long.MIN_VALUE, Long.MIN_VALUE + j2);
    }

    public static long doubleToUnsigned(double d) {
        return ((d > 9.223372036854776E18d ? 1 : (d == 9.223372036854776E18d ? 0 : -1)) > 0 ? 1 : null) != null ? (long) (d - 1.8446744073709552E19d) : (long) d;
    }

    public static long floatToUnsigned(float f) {
        return ((f > 9.223372E18f ? 1 : (f == 9.223372E18f ? 0 : -1)) > 0 ? 1 : null) != null ? (long) (f - 1.8446744E19f) : (long) f;
    }

    public static long parseLong(String str) {
        return parseLong(str, 10);
    }

    public static long parseLong(String str, int i) {
        Object obj = 1;
        if ((str == null ? 1 : null) != null) {
            throw new NullPointerException();
        }
        BigInteger bigInteger = new BigInteger(str, i);
        if (bigInteger.and(new BigInteger("FFFFFFFFFFFFFFFF", 16)).compareTo(bigInteger) == 0) {
            obj = null;
        }
        if (obj == null) {
            return bigInteger.longValue();
        }
        throw new NumberFormatException(str == null ? "For input string: " : "For input string: ".concat(str));
    }

    public static String toBinaryString(long j) {
        return toString(j, 2);
    }

    public static String toHexString(long j) {
        return toString(j, 16);
    }

    public static String toOctalString(long j) {
        return toString(j, 8);
    }

    public static String toString(long j) {
        return toString(j, 10);
    }

    public static String toString(long j, int i) {
        Object obj;
        if (i < 2) {
            obj = 1;
        } else if (i > 36) {
            int i2 = 1;
        } else {
            obj = null;
        }
        if (obj != null) {
            i = 10;
        }
        if ((j >= 0 ? 1 : null) != null) {
            return Long.toString(j, i);
        }
        char[] cArr = new char[64];
        i2 = cArr.length;
        Object obj2;
        do {
            long unsignedRemainder = unsignedRemainder(j, (long) i);
            j = unsignedDivide(j, (long) i);
            i2--;
            cArr[i2] = Character.forDigit((int) unsignedRemainder, i);
            if (j == 0) {
                obj2 = 1;
                continue;
            } else {
                obj2 = null;
                continue;
            }
        } while (obj2 == null);
        return new String(cArr, i2, cArr.length - i2);
    }

    public static long unsignedDivide(long j, long j2) {
        int i = 0;
        int i2 = 1;
        if ((j2 < 0 ? 1 : 0) != 0) {
            if (UnsignedCompare(j, j2) >= 0) {
                i = 1;
            }
            return (long) i;
        }
        if ((j >= 0 ? 1 : 0) != 0) {
            return j / j2;
        }
        long j3 = ((j >>> 1) / j2) << 1;
        if (UnsignedCompare(j - (j3 * j2), j2) < 0) {
            i2 = 0;
        }
        return ((long) i2) + j3;
    }

    public static long unsignedRemainder(long j, long j2) {
        Object obj = null;
        if ((j2 < 0 ? 1 : null) != null) {
            return UnsignedCompare(j, j2) < 0 ? j : j - j2;
        } else {
            if (j >= 0) {
                obj = 1;
            }
            if (obj != null) {
                return j % j2;
            }
            long j3 = j - ((((j >>> 1) / j2) << 1) * j2);
            if (UnsignedCompare(j3, j2) < 0) {
                j2 = 0;
            }
            return j3 - j2;
        }
    }

    public static double unsignedToDouble(long j) {
        return (j < 0 ? 1.8446744073709552E19d : 0.0d) + ((double) j);
    }

    public static float unsignedToFloat(long j) {
        return (j < 0 ? 1.8446744E19f : 0.0f) + ((float) j);
    }

    public static UnsignedLong valueOf(long j) {
        return new UnsignedLong(j);
    }

    public byte byteValue() {
        return (byte) ((int) this.fValue);
    }

    public int compareTo(UnsignedLong unsignedLong) {
        if ((unsignedLong == null ? 1 : null) == null) {
            return UnsignedCompare(this.fValue, unsignedLong.fValue);
        }
        throw new NullPointerException();
    }

    public double doubleValue() {
        return unsignedToDouble(this.fValue);
    }

    public boolean equals(Object obj) {
        UnsignedLong unsignedLong = !(obj instanceof UnsignedLong) ? null : (UnsignedLong) obj;
        return unsignedLong != null && unsignedLong.fValue == this.fValue;
    }

    public float floatValue() {
        return unsignedToFloat(this.fValue);
    }

    public int hashCode() {
        return (int) this.fValue;
    }

    public int intValue() {
        return (int) this.fValue;
    }

    public long longValue() {
        return this.fValue;
    }

    public short shortValue() {
        return (short) ((int) this.fValue);
    }

    public String toString() {
        return toString(this.fValue);
    }
}
